@@ -2,11 +2,14 @@ package Test::TCP;
 use strict;
 use warnings;
 use 5.00800;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 use base qw/Exporter/;
 use IO::Socket::INET;
 use Params::Validate ':all';
 use Test::SharedFork;
+use Test::More ();
+use Config;
+use POSIX;
 
 our @EXPORT = qw/ empty_port test_tcp wait_port /;
 
@@ -42,6 +45,9 @@ sub test_tcp {
 
         kill TERM => $pid;
         waitpid( $pid, 0 );
+        if (WIFSIGNALED($?) && (split(' ', $Config{sig_name}))[WTERMSIG($?)] eq 'ABRT') {
+            Test::More::diag("your server received SIGABRT");
+        }
     }
     elsif ( $pid == 0 ) {
         # child
